@@ -22,6 +22,7 @@
 
 #include <string.h>
 #include <libgnomedb/libgnomedb.h>
+#include <libgnomedb/gnome-db-window.h>
 #include <glade/glade-init.h>
 #include <glade/glade-build.h>
 
@@ -104,6 +105,9 @@ glade_module_register_widgets (void)
 	glade_register_widget (GNOME_DB_TYPE_ERROR_DIALOG,
 			       NULL, glade_standard_build_children,
 			       gnomedb_dialog_find_internal_child);
+	glade_register_widget (GNOME_DB_TYPE_FIND_DIALOG,
+			       NULL, glade_standard_build_children,
+			       gnomedb_dialog_find_internal_child);
 	glade_register_widget (GNOME_DB_TYPE_FORM,
 			       glade_standard_build_widget,
 			       NULL, NULL);
