@@ -282,7 +282,11 @@ sync_from_gda ()
 	gchar *epath;
 	gchar *type;
 	gchar *str;
-	
+
+	/* clear the previous data sources */
+	gnome_db_config_remove_section (GDA_CONFIG_SECTION_DATASOURCES);
+
+	/* add all data sources from the libgda configuration */
 	sections = gda_config_list_sections (GDA_CONFIG_BASE);
 	for (s = sections; s; s = s->next){
 		spath = g_strdup_printf ("%s/%s", GDA_CONFIG_BASE,
@@ -330,8 +334,11 @@ sync_to_gda (GConfClient *client,
 
 	key = gconf_entry_get_key (entry);
 	value = gconf_entry_get_value (entry);
-	if (value == NULL){
-		gda_config_remove_key (key);
+	if (value == NULL) {
+		if (gda_config_has_section (key))
+			gda_config_remove_section (key);
+		else
+			gda_config_remove_key (key);
 		return;
 	}
 
@@ -856,6 +863,7 @@ gnome_db_config_remove_data_source (const gchar *name)
 
 	dir = g_strdup_printf ("%s/%s", GDA_CONFIG_SECTION_DATASOURCES, name);
 	gnome_db_config_remove_section (dir);
+	gda_config_remove_section (dir);
 	g_free (dir);
 }
 
