@@ -215,12 +215,19 @@ gnome_db_dsn_config_new (void)
 GdaDataSourceInfo *
 gnome_db_dsn_config_get_info (GnomeDbDsnConfig *config)
 {
+	gint i;
 	GdaDataSourceInfo *dsn_info;
 
 	g_return_val_if_fail (GNOME_DB_IS_DSN_CONFIG (config), NULL);
 
 	dsn_info = g_new0 (GdaDataSourceInfo, 1);
 	dsn_info->name = g_strdup (gtk_entry_get_text (GTK_ENTRY (config->priv->wname)));
+	for (i = 0; i < strlen (dsn_info->name); i++) {
+		if (!g_ascii_isalnum (dsn_info->name[i])) {
+			dsn_info->name[i] = '_';
+		}
+	}
+
 	dsn_info->provider = g_strdup (
 		gnome_db_option_menu_get_selection (GTK_OPTION_MENU (config->priv->wprovider)));
 	dsn_info->cnc_string = g_strdup (
