@@ -608,10 +608,13 @@ const gchar *
 gnome_db_option_menu_get_selection (GtkOptionMenu *option_menu)
 {
 	GtkWidget *menu_item;
+	GtkWidget *menu;
 
 	g_return_val_if_fail (GTK_IS_OPTION_MENU (option_menu), NULL);
 
-	menu_item = option_menu->menu_item;
+	menu = gtk_option_menu_get_menu(option_menu);
+	menu_item = gtk_menu_get_active(menu);
+
 	if (GTK_IS_MENU_ITEM (menu_item)) {
 		return (const gchar *) g_object_get_data (G_OBJECT (menu_item),
 							  "GNOME:Database:MenuItemLabel");
